<!-- This file is compiled from plain-sessions/plain/sessions/README.md. Do not edit this file directly. -->

## Sessions - db backed

Manage sessions and save them in the database.

- associate with users?
- devices?
